import React from 'react';
import { ActionIconVariant, ColorScheme, MantineColor, MantineGradient, MantineNumberSize, MantineThemeOverride } from '@mantine/core';
import { AnimationControls, Target, TargetAndTransition, Transition, VariantLabels, Variants } from 'framer-motion';
export declare type BreakpointName = 'xs' | 'sm' | 'md' | 'lg' | 'xl';
export declare type ExpansionProps = {
    className?: string;
    color: ThemeColor;
    iconSize?: string | number;
    initialState?: 'collapsed' | 'expanded';
    radius?: MantineNumberSize;
    size?: MantineNumberSize;
    style?: React.CSSProperties;
    variant?: ActionIconVariant | 'gradient';
};
export declare type ExpansionButtonProps = {
    className?: string;
    color: ThemeColor;
    iconSize?: string | number;
    radius?: MantineNumberSize;
    size?: MantineNumberSize;
    style?: React.CSSProperties;
    variant?: ActionIconVariant | 'gradient';
};
export declare type ThemeColor = 'brand' | 'error' | 'info' | 'primary' | 'secondary' | 'success' | 'textPrimary' | 'warn';
export declare type ThemeGradient = 'brand' | 'error' | 'info' | 'primary' | 'secondary' | 'success' | 'warn';
export declare type NotifyType = 'error' | 'info' | 'loading' | 'success';
export declare type NotifyPosition = 'top-left' | 'top-center' | 'top-right' | 'bottom-left' | 'bottom-center' | 'bottom-right';
export declare type MessageWrapper = (message: string) => string;
export declare type IconsConfig = {
    error: React.ReactNode;
    info: React.ReactNode;
    success: React.ReactNode;
};
export declare type MessageWrappersConfig = {
    error: MessageWrapper;
    info: MessageWrapper;
    loading: MessageWrapper;
    success: MessageWrapper;
};
export declare type MotionConfig = {
    initial?: boolean | Target | VariantLabels;
    animate?: AnimationControls | TargetAndTransition | VariantLabels | boolean;
    exit?: TargetAndTransition | VariantLabels;
    mode?: 'wait' | 'sync' | 'popLayout';
    variants?: Variants;
    transition: Transition;
};
export declare type NotifyConfig = {
    autoClose: number;
    limit: number;
    position: NotifyPosition;
    icons: Partial<IconsConfig>;
    messageWrappers: Partial<MessageWrappersConfig>;
};
export declare type ColorConfig = Record<ThemeColor, MantineColor>;
export declare type GradientConfig = Record<ThemeColor, MantineGradient>;
export declare type Colors = Record<ThemeColor, string>;
export declare type Gradients = Record<ThemeGradient, {
    from: string;
    to: string;
}>;
export declare type MantineUIThemeContext = {
    applyGradients: boolean;
    colors: ColorConfig;
    colorScheme: ColorScheme;
    gradients: GradientConfig;
    notify: NotifyConfig;
    schemeOverrides: Record<string, MantineThemeOverride>;
    toggleColorScheme(): void | Promise<void>;
};
export declare type MantineUIThemeProviderProps = {
    applyGradients?: boolean;
    appThemeName: string;
    children?: React.ReactNode;
    colors?: Partial<ColorConfig>;
    gradients?: Partial<GradientConfig>;
    notify?: Partial<NotifyConfig>;
    schemeOverrides?: Record<string, MantineThemeOverride>;
};
